/*
    Title:    DCF77 library
    Author:   Volker Oth
    Date:     5/1999
    Purpose:  Decoding of the DCF77 real time signal.
    needed
    Software: AVR-GCC to compile, AVA to assemble and link
    needed
    Hardware: ATS90S8515 on STK200 board
    Note:     To contact me, mail to
                  volkeroth(at)gmx.de
*/

#ifndef DCF77_H
#define DCF77_H

#define DCF77_START (1500000/T_TCNT1)      /* >1.5 s  -> start */
#define DCF77_ZERO  ( 150000/T_TCNT1)      /* <150 ms -> zero */
#define DCF77_ONE   ( 250000/T_TCNT1)      /* <250 ms -> one  */

#define DCF77_STATUS_BIT         0         /* last bit received */
#define DCF77_STATUS_INIT        1         /* flag: start detected */
#define DCF77_STATUS_MIN_VALID   2         /* flag: minute info valid */
#define DCF77_STATUS_HOUR_VALID  3         /* flag: hour info valid */
#define DCF77_STATUS_DATE_VALID  4         /* flag: day info valid */




#define DCF77_BUFFER_SIZE 9

#define dcf77_start  dcf77_data[0]         /* start ID */ 
#define dcf77_second dcf77_data[1]         /* current second */
#define dcf77_minute dcf77_data[2]         /* decoded minute */ 
#define dcf77_hour   dcf77_data[3]         /* decoded hour */
#define dcf77_day    dcf77_data[4]         /* decoded day */
#define dcf77_wday   dcf77_data[5]         /* decoded weekday */
#define dcf77_month  dcf77_data[6]         /* decoded month */ 
#define dcf77_year   dcf77_data[7]         /* decoded year */ 
#define dcf77_status dcf77_data[8]         /* status bit field */ 

extern u08 dcf77_data[DCF77_BUFFER_SIZE];  /* buffer containing all decoded data */
extern void (*dcf77_call_fall)(void);
extern void (*dcf77_call_rise)(void);


void dcf77_bit_received(u08 bit);
void dcf77_init(void);

#endif