/*
    Title:    UART library
    Author:   Volker Oth
    Date:     5/1999
    Purpose:  Sending a block of data to uart.
    needed
    Software: AVR-GCC to compile, AVA to assemble and link
    needed
    Hardware: ATS90S8515 on STK200 board
    Note:     To contact me, mail to
                  volkeroth(at)gmx.de
*/

#include <io.h>
#include <signal.h>
#include "global.h"
#include "timer.h"     /* _before_ uart.h to define F_CPU ! */
#include "uart.h"

/* uart globals */
static volatile u08 *uart_data_ptr;
static volatile u08 uart_counter;


SIGNAL(SIG_UART_TRANS)      
/* signal handler for uart txd ready interrupt */
{
    uart_data_ptr++;

    if (--uart_counter)
        outp(*uart_data_ptr, UDR);       /* write byte to data buffer */
}


void uart_send(u08 *buf, u08 size)
/* send buffer <buf> to uart */
{
    if (!uart_counter) {
        /* write first byte to data buffer */
        uart_data_ptr  = buf;
        uart_counter   = size;
        outp(*buf, UDR);
    }
}


void uart_init(void)
/* initialize uart */
{
    /* enable RxD/TxD and ints */
    outp((1<<RXCIE)|(1<<TXCIE)/*|(1<<RXEN)*/|(1<<TXEN),UCR);       
    /* set baud rate */
    outp((u08)UART_BAUD_SELECT, UBRR);          
}